# Python package for the SYNERGY dataset

![PyPI](https://img.shields.io/pypi/v/synergy-dataset)

The `synergy-dataset` Python package is the easiest way to download and built
the SYNERGY dataset to your local device.

## Installation

SYNERGY requires Python 3.6 or later.

```sh
pip install synergy-dataset
```

## Getting started

See [https://github.com/asreview/synergy-dataset](https://github.com/asreview/synergy-dataset) for documentation and getting started.

## License

[MIT](/LICENSE)

## Contact

See [https://github.com/asreview/synergy-dataset](https://github.com/asreview/synergy-dataset) for contact details.
